@@ -47,7 +47,7 @@ pub(crate) async fn join_network(
 ) -> Result<(Node, Section)> {
     let (send_tx, send_rx) = mpsc::channel(1);
 
-    let span = trace_span!("bootstrap", name = %node.name());
+    let span = trace_span!("bootstrap");
 
     let state = Join::new(node, send_tx, incoming_conns);
 
@@ -196,8 +196,10 @@ impl<'a> Join<'a> {
                         }
 
                         info!(
-                            "Newer Join response for our prefix {:?} from {:?}",
-                            section_auth, sender
+                            "Newer Join response for us {:?}, SAP {:?} from {:?}",
+                            self.node.name(),
+                            section_auth,
+                            sender
                         );
                         section_key = section_auth.section_key();
                         let join_request = JoinRequest {
@@ -210,8 +212,10 @@ impl<'a> Join<'a> {
                             .await?;
                     } else {
                         warn!(
-                            "Newer Join response not for our prefix {:?} from {:?}",
-                            section_auth, sender,
+                            "Newer Join response not for us {:?}, SAP {:?} from {:?}",
+                            self.node.name(),
+                            section_auth,
+                            sender,
                         );
                     }
                 }
@@ -241,8 +245,10 @@ impl<'a> Join<'a> {
 
                     if section_auth.prefix.matches(&self.node.name()) {
                         info!(
-                            "Newer Join response for our prefix {:?} from {:?}",
-                            section_auth, sender
+                            "Newer Join response for us {:?}, SAP {:?} from {:?}",
+                            self.node.name(),
+                            section_auth,
+                            sender
                         );
                         section_key = section_auth.section_key();
                         let join_request = JoinRequest {
@@ -256,8 +262,10 @@ impl<'a> Join<'a> {
                             .await?;
                     } else {
                         warn!(
-                            "Newer Join response not for our prefix {:?} from {:?}",
-                            section_auth, sender,
+                            "Newer Join response not for us {:?}, SAP {:?} from {:?}",
+                            self.node.name(),
+                            section_auth,
+                            sender,
                         );
                     }
                 }
